Control-plane operations and requests for docx-mcp.
The control plane coordinates parsing, ingestion, and query operations for a single solution against the backing store.
Re-exports
pub use ingest::CsharpIngestReport;pub use ingest::CsharpIngestRequest;pub use ingest::RustdocIngestReport;pub use ingest::RustdocIngestRequest;pub use metadata::ProjectUpsertRequest;
Modules
Structs
- Docx
Control Plane - Facade for ingestion and query operations for a single solution store.
Enums
- Control
Error - Errors returned by control-plane operations.